﻿using DragAndDropDemo.Model;
using Syncfusion.UI.Xaml.TreeGrid;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Interactivity;

namespace DragAndDropDemo
{
    public class DragDropBehavior : Behavior<SfTreeGrid>
    {
        protected override void OnAttached()
        {
            base.OnAttached();
            AssociatedObject.RowDragDropController.Dropped += sfGrid_Dropped;
        }

        /// <summary>
        /// Customize the Dropped event.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void sfGrid_Dropped(object sender, TreeGridRowDroppedEventArgs e)
        {
            if (e.DropPosition != DropPosition.None)
            {
                //Get Dragging nodes
                ObservableCollection<TreeNode> draggingRecords = e.Data.GetData("Nodes") as ObservableCollection<TreeNode>;
                if (draggingRecords == null)
                    return;
                ViewModel model = AssociatedObject.DataContext as ViewModel;
                //Use Batch update to avoid data operatons in SfTreeGrid during records removing and inserting
                AssociatedObject.BeginInit();
                //Removes the dragging records from the underlying collection
                foreach (TreeNode item in draggingRecords)
                {
                    model.Employees.Remove(item.Item as EmployeeInfo);
                }
                //Find the target record index after removing the records
                int targetIndex = model.Employees.IndexOf(e.TargetNode.Item as EmployeeInfo);
                int insertionIndex = e.DropPosition == DropPosition.DropAbove ? targetIndex : targetIndex + 1;
                insertionIndex = insertionIndex < 0 ? 0 : insertionIndex;
                //Insert dragging records to the target position
                for (int i = draggingRecords.Count - 1; i >= 0; i--)
                {
                    model.Employees.Insert(insertionIndex, draggingRecords[i].Item as EmployeeInfo);
                }
                AssociatedObject.EndInit();
            }
        }


        protected override void OnDetaching()
        {
            base.OnDetaching();
            AssociatedObject.RowDragDropController.Dropped -= sfGrid_Dropped;
        }
    }
}
